#
# spec file for package juliaup
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# We will keep this for now
%global oldest_supported_julia_version 0.7.0
%global latest_julia_version 1.11.4

Name:           juliaup
Version:        1.17.13
Release:        1.1
Summary:        Julia installer and version multiplexer
License:        (0BSD OR MIT OR Apache-2.0) AND Apache-2.0 AND (Apache-2.0 OR BSL-1.0) AND (Apache-2.0 OR ISC OR MIT) AND (Apache-2.0 OR MIT) AND (Apache-2.0 OR Apache-2.0 WITH LLVM-exception OR MIT) AND (Apache-2.0 OR MIT OR Zlib) AND (Apache-2.0 OR MIT OR Zlib) AND (MIT OR Unlicense) AND (Apache-2.0 OR Zlib OR MIT) AND Apache-2.0 AND ISC AND MIT AND MPL-2.0 AND MIT
Group:          Development/Languages/Other
URL:            https://github.com/JuliaLang/juliaup
Source0:        https://github.com/JuliaLang/juliaup/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  cargo
BuildRequires:  cargo-packaging
BuildRequires:  zstd
Requires:       ca-certificates
Requires:       git
Requires(post): %{_sbindir}/update-alternatives
Requires(postun): %{_sbindir}/update-alternatives
ExclusiveArch:  %{rust_tier1_arches}

%description
A cross-platform installer for the Julia programming language.

The installer also bundles a full Julia version manager called juliaup.
One can use juliaup to install specific Julia versions, it alerts users
when new Julia versions are released and provides a convenient Julia
release channel abstraction.

%prep
%autosetup -a1 -p1

%build
%{cargo_build} --no-default-features -F binjulialauncher

%install
%{cargo_install} --no-default-features -F binjulialauncher

mkdir -p %{buildroot}%{_sysconfdir}/alternatives
ln -sf %{_sysconfdir}/alternatives/julia %{buildroot}%{_bindir}/julia

%post
%{_sbindir}/update-alternatives --install %{_bindir}/julia \
    julia %{_bindir}/julialauncher 10

%postun
if [ ! -f %{_bindir}/julialauncher ] ; then
    %{_sbindir}/update-alternatives --remove julia %{_bindir}/julialauncher
fi

%files
%license LICENSE
%doc README.md
%{_bindir}/juliaup
%{_bindir}/julialauncher
%ghost %{_bindir}/julia
%ghost %{_sysconfdir}/alternatives/julia

%changelog
* Sun Apr 13 2025 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 1.17.13:
  * support `x.y-nightly` channel to allow testing nightlies on release branches
  * If nightly check is going slowly inform user
  * Update deps
  * Fix default --project handling
  * Fix a call signature bug
  * Use correct way to show error message when launching from manifest
  * Use config setting for manifest launch
  * Launch exact Julia version from manifest
* Mon Dec 16 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update vendored dependencies.
  * resolves bsc#1233963
* Sun Oct 27 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 1.17.10:
  * Update src/command_update.rs
  * Prevent compiler warning without panicking
  * Update src/operations.rs
  * Add a eprintln! when the version db is updated
  * Delete a temp file if optimistic locking didn't work
  * Update a call signature
  * Allow longer read lock
  * Finish temp download of version db
  * Add `pr{number}~{arch}` variations to list
  * Update tests/command_initial_setup_from_launcher_test.rs
  * Print more things to stderr rather than stdout
  * Update tests/command_initial_setup_from_launcher_test.rs
  * Clean up error messages in the launcher
  * Use `rustls-tls-native-roots` for `reqwest` on FreeBSD (#1062)
  * Update the LTS version to 1.10
  * Also notify when updating nightly/pr channels
  * Add tests for --prune-linked
  * Use separate conditional steps for passing --check to rustfmt
  * Address comment
  * Fix windows check
  * Warn when linking to invalid julia binary
  * Error when attempting to launch invalid julia binary.
  * Address feedback
  * Phrasing and comments
  * Use reviewdog to suggest rustfmt diff
  * Add 'up' alias to self update
  * fix: first read, then delete.
  * feat: shows when updating symlinks
  * fix: styled message.
  * fix: better message
  * fix: old version too chatty
  * Get current juliaup channel with `juliaup self channel`
  * Add --prune-linked option for garbage collection
  * Remove unnecessary flag on Windows job
  * Check if path points to valid julia binary
  * Ensure Julia termintes when launcher terminates on Windows
  * Put AUR publishing in release channel
  * Support overriding an override
  * fix `is_juliaup_installed`
  * use is_terminal not atty
  * Check if the terminal is a TTY and not redirected
  * Don't import Term
  * Don't change terminal title
* Fri Sep 13 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Update to version 1.17.4:
  - Try a different PublisherDisplayName for store publication
  - Only check existing file permissions
  - Check file permissions before installing
  - Be more careful about existing installs
  - Fix package identity
  - Fix a bug
  - Package portable windows on win runner
  - Fix signing of windows portables
  - Sign more things
  - Update branding
  - Update deps
  - Error handling for `juliaup self update` (non-Windows)
  - add tests
  - add docs
  - support pr channels
  - use strongly typed Shell type for completions subcommand argument
  - Update version db
  - Update deps
  - Experiment with win package identity
  - Fix typo in README.md
  - Update deps
  - Update versiondb to include FreeBSD
  - Include FreeBSD when generating versiondb
  - Only modify shell scripts if that is selected
  - Delete old win shell script
  - Revert "adds some information on which channel is updating."
  - Fix a mistake
* Sat Jun  8 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.14.8
  * Dependencies update
* Fri Mar 22 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.14.7
  * CHANGES ARE WINDOWS SPECIFIC
- Update vendored dependencies
* Mon Feb 19 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Juliaup requires git and ca-certificates
* Thu Feb 15 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Change BuildRequires from rust+cargo to cargo
- Update to version 1.14.5:
  * Update CHANGELOG
  * Fix more StoreBroker bugs
  * Update CHANGELOG
  * Fix downgrade of powerhsell
  * Try a different fix for StoreBroker bug
  * Try a fix for StoreBroker
  * Fix typo in CHANGELOG
  * Update CHANGELOG
  * Update CHANGELOG
  * Work around a StoreBroker bug
  * Add CHANGELOG.md
  * Automatically generate release notes
  * Add documentation for nightly
  * Disable fail fast
  * Update dependencies
  * Fix formatting
  * Add some basic tests
  * Add nightly to getconfig1 api
  * Fix a compiler warning
  * Fix a warning
  * Implement nightly on Linux/Mac
  * Enable a symlink option
  * Add nightly update available status message
  * Format files
  * Don't fail fast
  * Fix status for nightly
  * Format files
  * Fix tests
  * Implement update for nightly on Windows
  * Change nightly config schema a bit
  * Try a different strategy for nightly
  * Update dependencies
  * Fix logic for stripping channel selector from command line
  * Update version db
  * Revert "feat: support nightly channel"
  * Add support for nightlies
  * Some minor cleanup
  * Make the nightly update interval configurable.
  * Use the actual nightly's version.
  * feat: support nightly channel
  * Add info about the completions command to the README
  * Add completions command
  * Only try to upload juliainstaller artifact if relevant
* Sun Jan 14 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Remove improve-error-message-if-version-or-channel-is-not-installed.patch as
  this is part of the patches now.
- Update to version 0.13.0:
  * Fix formatting
  * Move the clap def structs to separate file
  * change wording for comment for help text
  * format: run cargo fmt.
  * improvement: new message for `juliaup self uninstall command` if feature
    `selfupdate` is disabled
  * cleanup: add a period for each info/error messages.
  * refactor: remove redundant versiondb_data. also remove
    versiondb_data.available_versions since users cant access those
  * Fix usage of drop
  * Update all deps
  * Replace unmaintained action-rs actions
  * Don't detect ttyname if it is not needed
  * Describe 'julia +channel' after primary help text
  * juliaup-init.sh: backport changes from rustup
  * fixup: message should be more clear and generic
  * Try removing an unused import.
  * Only register the CTRL-C handler when it's safe to do so.
  * Format code.
  * Use double fork to prevent zombies.
  * launcher: replace parent process on supported platforms.
  * fix other error messages as well
  * fix error message on tests channel selection
  * fix an oopsie on one of the messages
  * run cargo fmt
  * remove redundant use
  * remove comment. irrelevant and unrelated now
  * make julialauncher have saner error messages for channels and versions
* Tue Dec 12 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Use binjulialauncher feature.
- Add /etc/alternatives/julia to ghost files.
* Sun Dec 10 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Add improve-error-message-if-version-or-channel-is-not-installed.patch
* Sun Dec 10 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Prepare specfile as an alternative for julia
* Tue Dec  5 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Remove cargo_config.
- Update to version 1.12.5:
  * Handle an error condition correctly
  * Return full 32 bit exit code from julialauncher
  * Update deps
  * follow symlinks
  * Sort versions in status output in natural order.
  * Bump actions/checkout from 3 to 4
  * Change triggers for rust fmt workflow
  * Run `cargo fmt` and check in the results
  * Update deps
  * Update deps
  * Move script around
  * Update deps
  * Human sort channel list
  * Remove license dialog from MSI installer
  * Update deps
  * Update deps
  * fix banner bg color
  * fix 491 to 493px wide
  * bitmaps for msi installer
  * Change to JULIAUP_DEPOT_PATH
  * Update LICENSE
  * Fix release.yml bug
  * Build portable versions
  * Fix gnu toolchain
  * Install correct mingw toolchain
  * Pick more specific toolchains
  * Add more fine control over binary creation
  * Update README
  * Move crates publishing to release channel
  * Change way secret is passed to cargo publish
  * Fix release build bug
  * Fix crates publication step
  * Add publish to crates step
  * Add docs for JULIAUP_HOME
  * Use JULIAUP_HOME instead of JULIA_DEPOT_PATH
* Sun Aug 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Fix specfile %%files section.
* Sun Aug 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Replace obsoleted `disabled` option with `manual`
* Thu Jul  6 2023 socvirnyl.estela@gmail.com
- Update to version 1.11.15:
  * CHANGELOG is irrelevant. Mostly Windows related. *
- Update vendored deps.
* Wed Jun 28 2023 socvirnyl.estela@gmail.com
- Update to version 1.11.0:
  * Add all binaries to Cargo.toml
  * Build everythin before running tests
  * Add metadata to Cargo.toml
  * Exclude some files from package
  * Only buildnecessary binaries in release workflow
  * Added a bit more error messages
  * Fix warning about symlink folder not being on PATH
  * Absolutize path for link command
  * chore: Release juliaup version 1.10.0
  * Add override documentation to README
  * Rename `override list` to `override status`
  * Add override tests
  * Prevent deletion of channel that is used in override
  * Format paths nicer on Windows
  * Use override in launcher
  * Add basic override management
  * Add basic override scaffolding
  * Add docs for JULIAUP_CHANNEL
  * Go back to simpler error implementation
  * Add tests for channel selection
  * Add JULIAUP_CHANNEL env var
  * Add SOCKS5 support on Linux/Mac
  * Use more standard syntax
  * Commit Cargo.lock
  * Fix formatting
  * Simplify http get request
  * Revert test.yml changes
  * Use reqwest
  * use optional input
  * work on better parsers
  * Reorder args
  * chore: added back ureq for macos deps
  * chore: initial reqwest migration
  * chore: generate new lockfile
  * chore: replace ureq to reqwest in Cargo.toml
  * fix: replace atty with is-terminal
  * Update version db (#606)
  * add a blame ignore revision file to avoid formatting changes to pollute git blame (#599)
  * run cargo format on all files (#595)
  * Update version db (#591)
  * remove double negative from input
  * add more cli parameters for automated install
  * Sleep for 30 seconds before and after purging the Fastly cache
  * Update juliaup.rs
  * Fix update to work with removed channels
  * Use better error messages
* Wed Mar  1 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update vendored dependencies.
- Restrict to Tier 1 architectures.
- Declare disk size to 8GB to avoid "No space left on device".
* Mon Feb 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Automatic update of vendored dependencies.
- Use zstd compression for tarballs.
* Wed Jan  4 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.8.16:
  * chore: Release juliaup version 1.8.16
  * Adjust README text
  * Update some names
  * Document installer command line args
  * chore: Release juliaup version 1.8.15
  * Update deps
  * Fix a warning
  * Add --channel option to self installer
  * Finish non-interactive install option
  * Add support for non-interactive install
  * add an ls alias for list
  * Add a comment
  * Purge the Fastly cache before downloading `versions.json`
  * Update version db
  * "Update Version DB": cc the user that triggered the workflow run
  * Update version db
  * Fix typo `uopdate` => `update` (#536)
  * Update version db
  * Update deps
- Remove 0000-fix-typo.patch. Fix already included in 1.8.16.
* Mon Dec 26 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Add 0000-fix-typo.patch
- Automatic update of vendored dependencies
* Sun Dec 18 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.8.14:
  * Update comment
  * Raise signal twice
  * Handle signals in julialauncher
  * Make get_juliaup_home_path work when no depot exists
  * Update deps
  * Add a missing conditional compile
  * fix typo in src/operations.rs error message
  * add more context to error-paths when handling juliaup startup script section
  * implement assumption that juliaup-path must be valid UTF-8
  * add indoc for better string literal formatting to dependencies
  * refactor shell-specific content generation into separate functions
  * move shell-script section header into global constant
  * Search depot path for existing juliaup dir
  * add unit tests for match_markers
  * add indoc as dev dependency for unit tests
  * fix some clippy lints in operations.rs
  * remove temporary rustfmt attribute to prevent formatting
  * adapt removal logic to work on bytes as well
  * adapt match_markers to work on bytes instead of strings
  * add generated byte vector to startup file instead of strings
  * generate vector of bytes instead of string for writing to file
  * add bstr to Cargo.toml and Cargo.lock
* Sun Dec 18 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Change to 4GB of memory in _constraints
* Sat Dec  3 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.8.12:
  * Fix typo
  * Fix a typo
  * Add a check phase to test workflow that runs on all platforms
  * Fix some platform specific errors and warnings
  * chore: Release juliaup version 1.8.11
  * Fix cond compile on macos
  * Unfix wrong target family
  * Fix typo on merge
  * Use more borrowed types where possible
  * Reset some functions return values back to Result
  * Change default versions db update interval to 24 hours
  * Add versions db update to add and update command
  * Update deps
  * Bump peter-evans/create-pull-request from 3 to 4
  * Various lints and minor improvements
  * Configure for target_os, not nonexistant family
  * Make 60 the default versions db update interval
  * Make the update interval between versions db updates a config
  * Update versions db on self update
  * Add a powerpoint schematic in devdocs
  * Update version db
  * Add alpha versions
  * Document releasepreview usage
  * Also add musl fix for release action.
  * Use sudo.
  * Fix quotes.
  * Musl build can't find gcc-musl.
  * chore: Release juliaup version 1.8.10
  * Enable second part of musl tests
  * Properly disable musl tests
  * Unify some output
  * Fix some unit tests
  * Update version db
  * Fix parse_versionstring
  * Generate better arch strings in semver
  * Enable ci tests of musl build
  * Disable musl tests for now
  * Use cross on Linux for tests
  * Add Juliaup version to juliaup info
  * Add musl build to tests
  * chore: Release juliaup version 1.8.9
  * Change shell script to serve musl on Linux
  * Add triplet to juliaup info
  * chore: Release juliaup version 1.8.8
  * Add info command
  * change to a redirect for developers to the wiki
  * add source build notes to the readme
* Fri Nov 25 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.8.7:
  * Fix bug in release workflow
  * Fix typo
  * In the "Update Version DB" PRs, add a note that the user must close and reopen the PR to trigger CI
  * Update version db
  * chore: Release juliaup version 1.8.5
  * Add musl builds
  * Fix some final things for the CI update story
  * Use local version db if newer than bundled
  * Fix a renaming bug
  * Update version db
  * Tweak cache update algorithm
  * Fix a bug
  * Trigger version db update from launcher
  * Add download of version db
  * Track latest structure in build.rs
  * Update version db (#468)
  * Delete tempfile
  * Update version db
  * Add tempfile
  * Use correct platform strings
  * Update version db workflow
  * chore: Release juliaup version 1.8.1
  * Remove diagnostic output
  * chore: Release juliaup version 1.8.0
  * Move LTS version to top in version udpate script
  * Delete versions.json
  * Replace build.rs logic
  * Update version db
  * New updatedb script
  * Fix typo
  * Update version db
  * Fix bug
  * Add versiondb folder
  * Progress version db
  * Progress on version db update
  * Fix bug in version db upload
  * Progress on update version db
  * Update versiondb process
  * Fix versiondb update
  * Add update version db script
  * Fix an error message
  * Add app installer info to README
- Update specfile. Remove the update-alternatives requirement
  It does not make sense since juliaup can have multiple julia versions.
- Add _constraints file to fix out of memory issues.
* Thu Nov 24 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.7.35:
  * Delete another file at self uninstall
  * Document self uninstall
  * Only delete own files with self uninstall
  * Add link to second Juliacon talk
  * Fix escaping in MSIX manifest
  * Describe using `expect` to automate install
  * Use correct secret name
  * Update Julia Computing cert info
  * Update deps
  * Go back to ~/.juliaup as the default install location
  * Use system certificates on Linux
* Thu Nov 24 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Remove strip option for debuginfo creation
* Mon Nov 21 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.7.27:
  * Remove release.toml
  * Fix versions
  * fix cargo lock (#442)
  * (cargo-release) version 1.7.26 (#441)
  * Add Julia 1.8.3 (#437)
  * Fix tiny typo in README (#423)
  * (cargo-release) start next development iteration 1.7.26-alpha.0
- Strip debug symbols through cargo_config.
- Set to no default features. We don't use self update and Windows.
* Sat Oct 15 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.7.25:
  * Update deps
  * (cargo-release) start next development iteration 1.7.25-alpha.0
* Sat Oct  1 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.7.24:
  * Add Julia 1.8.2
  * Update README.md (#398)
  * Update deps
* Wed Sep 14 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.7.23:
  * Add Julia 1.8.1
  * (cargo-release) start next development iteration 1.7.23-alpha.0
* Fri Aug 19 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.7.22:
  * Switch release channel to aarch64 on Mac
* Thu Aug 18 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.7.21:
  * Add Julia 1.8.0
  * Update deps (#383)
  * Include` juliaup list` in README (#376)
* Wed Aug 17 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- add fedora or rhel7 to specfile
* Sun Aug 14 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.7.20:
  * Add Julia 1.8.0-rc4
  * Fix another bug
  * Fix typo
  * Fix a bug
  * Fix typo
  * Fix a bug
  * Fix a typo
  * Compile different msix files
  * Fix a name in the app installer
  * Updates
  * Add VCLibs to app installer
  * Fix naming mismatch
  * Turn off some debug output
  * Update deps
  * Fix aws s3 sync call
  * Use aws cli directly on Windows
  * Fix workflow bugs
  * Fix things
  * Restructure deployment
  * Disable all deploy to GitHub releases
  * Don't run test workflow on version tags
  * Use concurrency for test workflow
  * Split workflow into test and build
  * Add tenant id for sign tool
  * Sign on Windows
  * Fix typo
  * Add Win AppInstaller (#371)
  * Update script that downloads bundled Julia versions
  * Fix typo
  * Fix bug
  * Bump indicatif
  * Move MSIX and store stuff to deploy folder
  * Don't compile get_proxy on Windows
  * Add debugger launch config
  * Use HttpClient for downloads on Windows
  * add missing 'url' argument to 'get_ureq_agent' calls
  * add trace-level logging regarding proxy resolution
  * implement proxy handling using environment variables
  * add env_proxy dependency in Cargo.toml
  * Fix a bug during remove of PATH on Mac
  * Update deps
  * Improve a "failed to open file" error message by printing the file path that we failed to open
  * Add minor channels for prerelease
  * Prepare for different build configs per target
  * Fixed typo about auto-update interval being in seconds, but actually meaning minutes.
  * Use previous windows version
  * Update deps
  * highlight and expand usage in readme
  * add usage tip on accessing channels
* Sat Aug  6 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.6.12:
  * (cargo-release) version 1.6.12
  * Update deps
  * Do not use native certs on Linux
  * (cargo-release) start next development iteration 1.6.12-alpha.0
  * (cargo-release) version 1.6.11
  * Add Julia 1.6.7
  * (cargo-release) start next development iteration 1.6.11-alpha.0
  * (cargo-release) version 1.6.10
  * Remove diagnostic code
  * Add diagnostic code
  * Fix config settings
  * Fix conditional compilation errors
  * Fix conditional compilation
  * (cargo-release) start next development iteration 1.6.10-alpha.0
  * (cargo-release) version 1.6.9
  * Update CI to use main as branch name
  * Use JULIAUP_SERVER in install scripts
  * Update CI to use main as branch name
  * Try to fix config again
  * Fix config handling
  * Use JULIAUP_SERVER in install scripts
  * Fix config error
  * Fix another bug
  * Fix bug
  * Remove config options
  * Use tls-native with native certs by default
  * Fix small bug
  * Simplify tls selection code
  * Undo unrelated stuff
  * Use valid semver identifiers for available_versions
  * Change the default self-install location
  * Check for same path deletion on self uninstall
  * Bump deps
  * Update deps
  * (cargo-release) start next development iteration 1.6.9-alpha.0
  * Bump actions/download-artifact from 2 to 3
  * Bump actions/upload-artifact from 2 to 3
  * remove useless default feature
  * fix; add native-certs feature as well
  * add native TLS support
* Thu Jul 21 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- use alternatives instead
- provide versioned julia
- conflicts other julia so use update-alternatives
* Tue Jul 19 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.6.8:
  * (cargo-release) version 1.6.8
  * Make aarch64 default on Mac starting with 1.8.0-rc3
  * (cargo-release) start next development iteration 1.6.8-alpha.0
  * (cargo-release) version 1.6.7
  * (cargo-release) start next development iteration 1.6.7-alpha.0
  * (cargo-release) version 1.6.6
  * (cargo-release) start next development iteration 1.6.6-alpha.0
* Sat Jul 16 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.6.5:
  * (cargo-release) version 1.6.5
  * Add Julia 1.8.0-rc3
  * (cargo-release) start next development iteration 1.6.5-alpha.0
  * (cargo-release) version 1.6.4
  * Fix a version bug
  * Update to Rust 2021 edition
  * Update window crate
  * Update deps
  * (cargo-release) start next development iteration 1.6.4-alpha.0
  * (cargo-release) version 1.6.3
* Wed Jun  8 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.6.4:
  * (cargo-release) version 1.6.4
  * Fix a version bug
  * Update to Rust 2021 edition
  * Update window crate
  * Update deps
  * (cargo-release) start next development iteration 1.6.4-alpha.0
* Fri Jun  3 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.6.3:
  * (cargo-release) version 1.6.3
  * Add Julia 1.8.0-rc1
  * (cargo-release) start next development iteration 1.6.3-alpha.0
  * (cargo-release) version 1.6.2
  * Update to Julia 1.7.3
  * Update clap
  * (cargo-release) start next development iteration 1.6.2-alpha.0
  * (cargo-release) version 1.6.1
  * Update deps
  * Add Julia 1.6.6 support
* Thu May 26 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.6.2:
  * (cargo-release) version 1.6.2
  * Update to Julia 1.7.3
  * Update clap
  * (cargo-release) start next development iteration 1.6.2-alpha.0
  * (cargo-release) version 1.6.1
  * Update deps
  * Add Julia 1.6.6 support
  * Remove 1.8.0-beta2
  * Add 1.8.0-beta2 and 1.8.0-beta3
  * (cargo-release) start next development iteration 1.6.1-alpha.0
* Sat Apr  2 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.6.1~0:
  * (cargo-release) version 1.6.1
  * Update deps
  * Add Julia 1.6.6 support
  * Remove 1.8.0-beta2
  * Add 1.8.0-beta2 and 1.8.0-beta3
  * (cargo-release) start next development iteration 1.6.1-alpha.0
* Tue Mar 29 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.6.0~0:
  * (cargo-release) version 1.6.0
  * Add test for list command
  * Add list command
  * fix clap-related deprecations
  * Bump dialoguer from 0.9.0 to 0.10.0
  * Bump actions/checkout from 2 to 3
  * Add dependabot configuration
  * Make `winres` a Windows-only build dependency
  * (cargo-release) start next development iteration 1.5.39-alpha.0
* Mon Mar 14 2022 William Brown <william.brown@suse.com>
- Update to resolve bsc#1196972 CVE-2022-24713 - Regex DOS
* Thu Mar  3 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec (1.5.37)
